@@ -1,7 +1,7 @@
 "rakingratio" <-
 function(Xs,piks,t,q=rep(1,times=length(piks)))
 {
-require(MASS)
+library(MASS)
 ITERATIONS=300
 EPS=.Machine$double.eps	
 tol=.Machine$double.eps
@@ -22,7 +22,7 @@ tc1=c(d1%*%Xs1)
 #####################################################
 # definition of the exponential rakingratio function
 #####################################################
-Fcal<-function(u,v)   exp(u*v)
+Fcal<-function(u,v)   F=exp(u*v)
 #####################################################
 # definition of the derivative of
 # the exponential rakingratio function
@@ -65,7 +65,7 @@ z=lambda-lambda1
 if( (t(z)%*%z<EPS)) break
 lambda=lambda1
 }
-if(i==ITERATIONS) warning("impossible to solve the program")
+if(i==ITERATIONS) cat("\nImpossible to solve the program\n")
 ###########################################################
 g1=rep(0,times=n1)
 for(k in 1:n1) g1[k]=Fcal(t(lambda)%*%Xs1[k,],q1[k])
